@@ -1,6 +1,14 @@
 import os
-import urllib.request
 import zipfile
+import tarfile
+from six.moves import urllib
+
+
+# Fix error when downloading dataset from torchvision
+# https://github.com/pytorch/vision/issues/1938#issuecomment-790730080
+opener = urllib.request.build_opener()
+opener.addheaders = [('User-agent', 'Mozilla/5.0')]
+urllib.request.install_opener(opener)
 
 
 def download(url, path):
@@ -12,9 +20,6 @@ def download(url, path):
     if os.path.exists(file_name):
         print(f"Dataset already downloaded at {file_name}.")
     else:
-        opener = urllib.request.build_opener()
-        opener.addheaders = [('User-agent', 'Wget/1.20.3 (linux-gnu)')]
-        urllib.request.install_opener(opener)
         urllib.request.urlretrieve(url, file_name, ProgressBar().update)
 
     return file_name
@@ -22,9 +27,14 @@ def download(url, path):
 
 def unzip(path):
     directory_path = os.path.dirname(path)
+    with zipfile.ZipFile(path, 'r') as zip_file:
+        zip_file.extractall(directory_path)
 
-    with zipfile.ZipFile(path, 'r') as zip_ref:
-        zip_ref.extractall(directory_path)
+
+def untar(path):
+    directory_path = os.path.dirname(path)
+    with tarfile.TarFile(path, 'r') as tar_file:
+        tar_file.extractall(directory_path)
 
 
 class ProgressBar:
@@ -46,3 +56,7 @@ class ProgressBar:
         print("\r|%s| %s%%" % (pbar, percent), end="\r")
         if self.count == total_size:
             print()
+
+    def end(self, total_size):
+        self.count = total_size
+        self.update(None, 0, total_size)
